@@ -1,9 +1,10 @@
+#include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 
 #include "ipc.h"
 
-int get_ipc_address(char *address, size_t size) {
+int get_ipc_path(char *path, size_t size) {
 	const char *wayland_display = getenv("WAYLAND_DISPLAY");
 	const char *xdg_runtime_dir = getenv("XDG_RUNTIME_DIR");
 	if (!wayland_display || !wayland_display[0]) {
@@ -15,6 +16,5 @@ int get_ipc_address(char *address, size_t size) {
 		return -1;
 	}
 
-	return snprintf(address, size, "unix:%s/fr.emersion.kanshi.%s",
-			xdg_runtime_dir, wayland_display);
+	return snprintf(path, size, "%s/fr.emersion.kanshi.%s", xdg_runtime_dir, wayland_display);
 }
